@@ -3,7 +3,7 @@
  * Date  : 05-08-2005
  * Description : Handle communications with flickr.com
  *
- * Copyright 2005 by M. Asselstine
+ * Copyright 2005,2007 by M. Asselstine
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -71,7 +71,14 @@ public:
     void sendLicensesRequest();
 
     void sendTagsRequest(const QString &token, const QString &);
-    void sendPhoto(const QString &token, Photo *photo);
+
+    /** Sends a photo to flickr.
+     *  @param The user's auth token
+     *  @param photo Pointer fo Photo to send
+     *  @return pointer to the KIO::TransferJob handling the transfer, or 0 on failure
+     */
+    KIO::TransferJob* sendPhoto(const QString &token, Photo *photo);
+
     void createPhotoset(const QString &, const QString &, const QString &);
     void addPhoto2Photoset(const QString &, const QString &, const QString &);
 
@@ -118,7 +125,13 @@ private:
      */
     void handleLicensesResponse(const QString& str);
 
-    QByteArray getEXIFData(QFile &in);
+    /** Writes a photo that has been manipulated by size or rotation
+     *  ensuring that the EXIF data provided is re-associated with
+     *  the photo.
+     *  @param out Output stream being used to write the photo to
+     *  @param in Image
+     *  @param exif The EXIF data to put with the image
+     */
     void writePhotoWithEXIF(QTextStream &out, QImage &in, QByteArray &exif);
 
     QString m_APIKey;
