@@ -27,11 +27,13 @@
 #include "kflickrwidget.h"
 #include "photolistview.h"
 #include "authcomplete.h"
+#include "uploadprogress.h"
 #include "photoproperties.h"
 #include "authquestiondlg.h"
 
 #include <krun.h>
 #include <qvbox.h>
+#include <qfile.h>
 #include <qlabel.h>
 #include <qframe.h>
 #include <qevent.h>
@@ -48,12 +50,16 @@
 #include <qsizepolicy.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 #include <qscrollview.h>
 #include <qdragobject.h>
 #include <qpushbutton.h>
 #include <kpushbutton.h>
 #include <qmessagebox.h>
 #include <kapplication.h>
+#include <kstandarddirs.h>
+#include <kio/jobclasses.h>
+
 
 kflickrWidget::kflickrWidget(QWidget* parent, const char* name, WFlags fl)
     : kflickrWidgetUI(parent,name,fl)
@@ -146,6 +152,9 @@ kflickrWidget::~kflickrWidget()
     KConfig *config = kapp->config();
     QHeader *hdr = m_photolist->header();
 
+    // Do a session backup
+    m_photolist->doBackup(locateLocal("appdata", "backup.xml"));
+
     // set the group
     config->setGroup("KFlickrWidget");
 
@@ -222,6 +231,31 @@ void kflickrWidget::addPhotos(const KURL::List &urls)
     }
 }
 
+void kflickrWidget::show()
+{
+    static bool firsttime = TRUE;
+    QFile f(locateLocal("appdata", "backup.xml"));
+
+    kflickrWidgetUI::show();
+
+    if( firsttime && f.exists() )
+    {
+        firsttime = FALSE;
+        if( KMessageBox::questionYesNo(this,
+            i18n("Previously KFlickr either closed unexpectedly or you quit before uploading\
+                  your photographs. Do you wish to restore your previous session?"),
+            i18n("Restore previous session?")) == KMessageBox::Yes )
+        {
+            m_photolist->doRestore(locateLocal("appdata", "backup.xml"));
+            updateAvailableActions();
+        }
+        else
+        {
+            f.remove();
+        }
+    }
+}
+
 void kflickrWidget::uploadPhotos()
 {
     if( m_photolist->childCount() > 0 )
@@ -229,6 +263,9 @@ void kflickrWidget::uploadPhotos()
         m_uploadInProgress = true;
         m_photolist->clearSelection();
 
+        // Do a session backup
+        m_photolist->doBackup(locateLocal("appdata", "backup.xml"));
+
         // display the progress dialog
         showUploadProgress(m_photolist->childCount());
 
@@ -237,10 +274,6 @@ void kflickrWidget::uploadPhotos()
     }
 }
 
-
-/*!
-    \fn kflickrWidget::uploadNextPhoto()
- */
 void kflickrWidget::uploadNextPhoto()
 {
     // get last photo in list
@@ -248,14 +281,15 @@ void kflickrWidget::uploadNextPhoto()
 
     if( item )
     {
-        m_comm.sendPhoto(m_userTokens[m_currentUserIndex], &(item->photo()));
-        updateUploadProgress(i18n("Sending Photo - %1").arg(item->photo().URL().filename()));
+        KIO::TransferJob* job;
+        job = m_comm.sendPhoto(m_userTokens[m_currentUserIndex], &(item->photo()));
+        updateUploadProgress(item->photo().preview(), job);
     }
     else
     {
         // The progress dialog will sometime pop back up if
         // it is left with steps to do, so update to make %100
-        updateUploadProgress(i18n("Done"));
+        updateUploadProgress(QPixmap());
         m_uploadInProgress = false;
         hideUploadProgress();
 
@@ -264,10 +298,6 @@ void kflickrWidget::uploadNextPhoto()
     }
 }
 
-
-/*!
-    \fn kflickrWidget::photoUploadedOK(const QString &photoID)
- */
 void kflickrWidget::photoUploadedOK(const QString &photoID)
 {
 
@@ -292,14 +322,13 @@ void kflickrWidget::photoUploadedOK(const QString &photoID)
         delete item;
     }
 
+    // Do a session backup
+    m_photolist->doBackup(locateLocal("appdata", "backup.xml"));
+
     // upload the next one
     uploadNextPhoto();
 }
 
-
-/*!
-    \fn kflickrWidget::cancelUpload()
- */
 void kflickrWidget::cancelUpload()
 {
     m_uploadInProgress = false;
@@ -307,10 +336,6 @@ void kflickrWidget::cancelUpload()
     hideUploadProgress();
 }
 
-
-/*!
-    \fn kflickrWidget::slotAuthorizeNewUser()
- */
 void kflickrWidget::authorizeNewUser()
 {
     AuthQuestionDlg dlg( this );
@@ -325,10 +350,6 @@ void kflickrWidget::authorizeNewUser()
     m_comm.sendFROBRequest();
 }
 
-
-/*!
-    \fn kflickrWidget::doUserAuthentication( const QString &frob )
- */
 void kflickrWidget::doUserAuthentication( const QString &frob )
 {
     AuthCompleteDlg dlg( this );
@@ -419,10 +440,6 @@ void kflickrWidget::addUser( const QString &name, const QString &token, const QS
                 i18n("A new user '%1' has been added successfully.").arg(name) );
 }
 
-
-/*!
-    \fn kflickrWidget::setActiveUser( const QString & )
- */
 void kflickrWidget::setActiveUser( const QString &name )
 {
     // update combobox
@@ -454,10 +471,6 @@ void kflickrWidget::removePhotos()
     updateAvailableActions();
 }
 
-
-/*!
-    \fn kflickrWidget::dropSlot( QDropEvent *e, QListViewItem *after )
- */
 void kflickrWidget::dropSlot( QDropEvent *e, QListViewItem *after )
 {
     QString text;
@@ -506,30 +519,27 @@ void kflickrWidget::showUploadProgress(int numPhotos)
     // create the progress dialog if it does not yet exist
     if( m_progressDlg == 0L )
     {
-        m_progressDlg = new KProgressDialog(this, "m_progressDlg");
-        m_progressDlg->progressBar()->setTextEnabled(false);
-        m_progressDlg->setCaption(i18n("Upload Progress"));
-        m_progressDlg->setAutoClose(false);
-        m_progressDlg->setModal(true);
+        m_progressDlg = new UploadProgress(this, "m_progressDlg");
 
         // Progress dialog connections
         connect(m_progressDlg, SIGNAL(cancelClicked()), this, SLOT(cancelUpload()));
     }
 
     // tune the progress dialog accordingly
-    m_progressDlg->progressBar()->setTotalSteps(numPhotos);
-    m_progressDlg->progressBar()->setValue(0);
+    m_progressDlg->setNumPhotos(numPhotos);
+    m_progressDlg->setNumCompleted(-1);
     m_progressDlg->show();
 }
 
-void kflickrWidget::updateUploadProgress(const QString &str)
+void kflickrWidget::updateUploadProgress(const QPixmap &pixmap, KIO::TransferJob* job)
 {
+    Q_UNUSED(job);
+
     // set text
-    m_progressDlg->setLabel(str);
+    m_progressDlg->setPixmap(pixmap);
 
     // move progress bar
-    if( m_progressDlg->progressBar()->totalSteps() != m_photolist->childCount())
-        m_progressDlg->progressBar()->advance(1);
+    m_progressDlg->advance(1);
 }
 
 void kflickrWidget::handleCommError(const QString &errstr)
