@@ -732,8 +732,12 @@ void PhotoProperties::matchSizingsToPhotoLayout()
     // update our portrait sizings flag accordingly
     m_portraitSizings = !m_portraitSizings;
 
-    // Update the size for the photo or photos being edited
-    updateSize(QString("%1 %2x%3").arg(m_sizes->currentText()).arg(m_width->value()).arg(m_height->value()));
+    // Update the size for the photo being edited. Not relavent for batch mode as we only want to have
+    // the size change on explicit user input.
+    if(!m_batchMode)
+    {
+        updateSize(QString("%1 %2x%3").arg(m_sizes->currentText()).arg(m_width->value()).arg(m_height->value()));
+    }
 }
 
 
