@@ -36,10 +36,22 @@ class PreviewDlg : public PreviewUI
 Q_OBJECT
 
 public:
+    /**
+     * Constructor.
+     * @param parent Pointer to parent widget
+     * @param name Widget name for this dialog
+     */
     PreviewDlg(QWidget *parent = 0, const char *name = 0);
+
+    /** Destructor */
     ~PreviewDlg();
-    
+
+    /**
+     * Set the URL and the rotation of the photo to preview.
+     * @param url URL of the file for the photo
+     * @param rotation Rotation in degrees to apply to the photo preview image.
+     */
     void displayPhoto(const KURL &url, int rotation);
 };
 
-#endif
+#endif // PREVIEWDLG_H
